@@ -22,14 +22,15 @@ def eventhook_factory(event_name: str, config: dict):
     data = {"name": event_name, "realms": config.get("realms", [])}
     try:
         class_ = getattr(eventhooks, event_type)
-    except (AttributeError) as e:
-        logger.error(f"Could not import 'eventhooks' type '{event_type}'. Error: {str(e)}.")
+    except (AttributeError) as e_attr:
+        logger.error(f"Could not import 'eventhooks' type '{event_type}'. Error: {str(e_attr)}.")
         return None
     logger.debug(f"Trying to configure '{event_type}' with '{config}'.")
     if event_type == "AwsSesEmailHook":
         data["sender"] = config.get("sender", "")
         data["sender_name"] = config.get("sender_name", "")
         data["recipients"] = config.get("recipients", [])
+        data["region"] = config.get("region", "")
     elif event_type == "SimpleEmailHook":
         data["host"] = config.get("host", "")
         data["port"] = config.get("port", 0)
